searchNodes=[{"ref":"Cldr.Calendar.html","title":"Cldr.Calendar","type":"behaviour","doc":"Calendar functions for calendars compatible with Elixir&#39;s Calendar behaviour. Cldr.Calendar supports the creation of calendars that are variations on the proleptic Gregorian calendar. It also adds additional functions, defined by the Cldr.Calendar behaviour, to support these derived calendars. The common purpose of these derived calendars is to support the creation and use of financial year calendars that are commonly used in business. There are two general types of calendars supported: month calendars that mirror the monthly structure of the proleptic Gregorian calendar but which are deemed to start the year in a month other than January. week calendars that are defined to have a 52 week structure (53 weeks in a long year). These calendars can be configured to start or end on the first, last or nearest day to the beginning or end of a Gregorian month. The main intent behind this structure is to have each year start and end on the same day of the week with a consistent 13-week quarterly structure than enables a more straight forware comparison with same-period-last-year financial performance."},{"ref":"Cldr.Calendar.html#c:calendar_base/0","title":"Cldr.Calendar.calendar_base/0","type":"callback","doc":"Returns the calendar basis. Returns either :week or :month"},{"ref":"Cldr.Calendar.html#c:cldr_calendar_type/0","title":"Cldr.Calendar.cldr_calendar_type/0","type":"callback","doc":"Returns the CLDR calendar type. Only algorithmic calendars are considered in this implementation"},{"ref":"Cldr.Calendar.html#current/2","title":"Cldr.Calendar.current/2","type":"function","doc":"Returns the current date or date range for a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year, :quarter, :month, :week or :day Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples"},{"ref":"Cldr.Calendar.html#date_from_iso_days/2","title":"Cldr.Calendar.date_from_iso_days/2","type":"function","doc":"Returns a date represented by a number of days since the start of the epoch. The start of the epoch is the date 0000-01-01. Argumenets iso_days is an integer representing the number of days since the start of the epoch. calendar is any module that implements the Calendar and Cldr.Calendar behaviours Returns a Date.t() Example iex&gt; Cldr.Calendar.date_from_iso_days 737425, Calendar.ISO ~D[2019-01-01] iex&gt; Cldr.Calendar.date_from_iso_days 366, Calendar.ISO ~D[0001-01-01] iex&gt; Cldr.Calendar.date_from_iso_days 0, Calendar.ISO ~D[0000-01-01]"},{"ref":"Cldr.Calendar.html#date_from_tuple/2","title":"Cldr.Calendar.date_from_tuple/2","type":"function","doc":"Returns a Date.t from a date tuple of {year, month, day} and a calendar. Arguments {year, month, day} is a tuple representing a date calendar is any module implementing the Calendar and Cldr.Calendar behaviours Returns a Date.t Examples iex&gt; Cldr.Calendar.date_from_tuple {2019, 3, 25}, Cldr.Calendar.Gregorian %Date{calendar: Cldr.Calendar.Gregorian, day: 25, month: 3, year: 2019} iex&gt; Cldr.Calendar.date_from_tuple {2019, 2, 29}, Cldr.Calendar.Gregorian {:error, :invalid_date}"},{"ref":"Cldr.Calendar.html#date_to_iso_days/1","title":"Cldr.Calendar.date_to_iso_days/1","type":"function","doc":"Returns the number of days since the start of the epoch. The start of the epoch is the date 0000-01-01. Argumenets date is any Date.t() Returns The integer number of days since the epoch for the given date. Example iex&gt; Cldr.Calendar.date_to_iso_days ~D[2019-01-01] 737425 iex&gt; Cldr.Calendar.date_to_iso_days ~D[0001-01-01] 366 iex&gt; Cldr.Calendar.date_to_iso_days ~D[0000-01-01] 0"},{"ref":"Cldr.Calendar.html#date_to_string/1","title":"Cldr.Calendar.date_to_string/1","type":"function","doc":"Formats a date into a string representation Example iex&gt; import Cldr.Calendar.Sigils iex&gt; Cldr.Calendar.date_to_string ~d[2019-12-04] &quot;2019-12-04&quot; iex&gt; Cldr.Calendar.date_to_string ~d[2019-23-04]NRF &quot;2019-W23-4&quot;"},{"ref":"Cldr.Calendar.html#day_of_era/1","title":"Cldr.Calendar.day_of_era/1","type":"function","doc":"Returns the {day_of_era, era} for a date. Arguments date is any Date.t() Returns a the days since the start of the era and the era of the year as a tuple Examples iex&gt; Cldr.Calendar.day_of_era ~D[2019-01-01] {737060, 1} iex&gt; Cldr.Calendar.day_of_era Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF) {737093, 1} iex&gt; Cldr.Calendar.day_of_era Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF) {737456, 1}"},{"ref":"Cldr.Calendar.html#day_of_week/1","title":"Cldr.Calendar.day_of_week/1","type":"function","doc":"See Date.day_of_week/1."},{"ref":"Cldr.Calendar.html#day_of_year/1","title":"Cldr.Calendar.day_of_year/1","type":"function","doc":"Returns the day of the year for a date. Arguments date is any Date.t() Returns a the day of the year as an integer Examples iex&gt; import Cldr.Calendar.Sigils iex&gt; Cldr.Calendar.day_of_year ~d[2019-01-01] 1 iex&gt; Cldr.Calendar.day_of_year ~d[2016-12-31] 366 iex&gt; Cldr.Calendar.day_of_year ~d[2019-12-31] 365 iex&gt; Cldr.Calendar.day_of_year ~d[2019-52-07]NRF 365 iex&gt; Cldr.Calendar.day_of_year ~d[2012-53-07]NRF 372"},{"ref":"Cldr.Calendar.html#days_in_month/1","title":"Cldr.Calendar.days_in_month/1","type":"function","doc":"See Date.days_in_month/1."},{"ref":"Cldr.Calendar.html#c:days_in_year/1","title":"Cldr.Calendar.days_in_year/1","type":"callback","doc":"Returns the number of days in a year"},{"ref":"Cldr.Calendar.html#default_calendar/0","title":"Cldr.Calendar.default_calendar/0","type":"function","doc":"Returns the default calendar."},{"ref":"Cldr.Calendar.html#first_day_of_year/1","title":"Cldr.Calendar.first_day_of_year/1","type":"function","doc":"Returns the first date of a year for a Date.t. Arguments date is any Date.t() Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar.first_day_of_year ~D[2019-12-01] ~D[2019-01-01]"},{"ref":"Cldr.Calendar.html#first_day_of_year/2","title":"Cldr.Calendar.first_day_of_year/2","type":"function","doc":"Returns the first date of a year in a calendar. Arguments year is any year calendar is any module that implements the Calendar and Cldr.Calendar behaviours Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar.first_day_of_year 2019, Cldr.Calendar.Gregorian %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 1, year: 2019} iex&gt; Cldr.Calendar.first_day_of_year 2019, Cldr.Calendar.NRF %Date{calendar: Cldr.Calendar.NRF, day: 1, month: 1, year: 2019}"},{"ref":"Cldr.Calendar.html#first_gregorian_day_of_year/2","title":"Cldr.Calendar.first_gregorian_day_of_year/2","type":"function","doc":"Returns the gregorian date of the first day of of a year for a calendar. Arguments year is any integer year number Examples iex&gt; Cldr.Calendar.first_gregorian_day_of_year 2019, Cldr.Calendar.Gregorian %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 1, year: 2019} iex&gt; Cldr.Calendar.first_gregorian_day_of_year 2019, Cldr.Calendar.NRF %Date{calendar: Cldr.Calendar.Gregorian, day: 3, month: 2, year: 2019}"},{"ref":"Cldr.Calendar.html#friday/0","title":"Cldr.Calendar.friday/0","type":"function","doc":"Returns the ordinal day number representing Friday."},{"ref":"Cldr.Calendar.html#interval/3","title":"Cldr.Calendar.interval/3","type":"function","doc":"Returns an Enumerable list of dates of a given precision of either :years, :quarters, :months, :weeks or :days Arguments date_from is a any Date.t that is the start of the sequence date_to_or_count is upper bound of the sequence as a Date.t or the number of dates in the sequence to be generated precision is one of :years, :quarters, :months, :weeks or :days The sequence is generated starting with date_from until the next date in the sequence would be after date_to. Notes The sequence can be in ascending or descending date order based upon whether date_from is greater than date_to. Returns A list of dates Examples iex&gt; import Cldr.Calendar.Sigils Cldr.Calendar.Sigils iex&gt; d = ~d[2019-01-31] %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019} iex&gt; d2 = ~d[2019-05-31] %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019} iex&gt; Cldr.Calendar.interval d, 3, :months [ %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019} ] iex&gt; Cldr.Calendar.interval d, d2, :months [ %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 4, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019} ]"},{"ref":"Cldr.Calendar.html#interval_stream/3","title":"Cldr.Calendar.interval_stream/3","type":"function","doc":"Returns an a Stream function than can be lazily enumerated. This function has the same arguments and provides the same functionality as interval/3 exept that it is lazily evaluated. Arguments date_from is a any Date.t that is the start of the sequence date_to_or_count is upper bound of the sequence as a Date.t or the number of dates in the sequence to be generated precision is one of :years, :quarters, :months, :weeks or :days The sequence is generated starting with date_from until the next date in the sequence would be after date_to. Notes The sequence can be in ascending or descending date order based upon whether date_from is greater than date_to. Returns A list of dates Examples iex&gt; import Cldr.Calendar.Sigils Cldr.Calendar.Sigils iex&gt; d = ~d[2019-01-31] %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019} iex&gt; d2 = ~d[2019-05-31] %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019} iex&gt; Cldr.Calendar.interval_stream(d, 3, :months) |&gt; Enum.to_list [ %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019} ] iex&gt; Cldr.Calendar.interval_stream(d, d2, :months) |&gt; Enum.to_list [ %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 4, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019} ]"},{"ref":"Cldr.Calendar.html#iso_days_to_day_of_week/1","title":"Cldr.Calendar.iso_days_to_day_of_week/1","type":"function","doc":"Returns the day of the week for a given iso_day_number Arguments iso_day_number is the number of days since the start of the epoch. See Cldr.Calendar.date_to_iso_days/1 Returns An integer representing a day of the week where Monday is represented by 1 and Sunday is represented by 7 Examples iex&gt; days = Cldr.Calendar.date_to_iso_days ~D[2019-01-01] iex&gt; Cldr.Calendar.iso_days_to_day_of_week(days) == Cldr.Calendar.tuesday true"},{"ref":"Cldr.Calendar.html#iso_week_of_year/1","title":"Cldr.Calendar.iso_week_of_year/1","type":"function","doc":"Returns the ISO week number for a date. Arguments date is any Date.t() Returns a the ISO week of the year as an integer or {:error, :not_defined} is the calendar does not support the concept of weeks. Examples iex&gt; import Cldr.Calendar.Sigils iex&gt; Cldr.Calendar.iso_week_of_year ~d[2019-01-01] {2019, 1} iex&gt; Cldr.Calendar.iso_week_of_year ~d[2019-02-01] {2019, 5} iex&gt; Cldr.Calendar.iso_week_of_year ~d[2019-52-01]NRF {2020, 4} iex&gt; Cldr.Calendar.iso_week_of_year ~d[2019-26-01]NRF {2019, 30} iex&gt; Cldr.Calendar.iso_week_of_year ~d[2019-12-01]Julian {:error, :not_defined}"},{"ref":"Cldr.Calendar.html#c:iso_week_of_year/3","title":"Cldr.Calendar.iso_week_of_year/3","type":"callback","doc":"Returns a tuple of {year, week_in_year} for a given year, month or week, and day for a a calendar. The iso_week_of_year is calculated based on the ISO calendar."},{"ref":"Cldr.Calendar.html#last_day_of_year/1","title":"Cldr.Calendar.last_day_of_year/1","type":"function","doc":"Returns the last date of a year for a Date.t. Arguments date is any Date.t() Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar.last_day_of_year ~D[2019-01-01] ~D[2019-12-31]"},{"ref":"Cldr.Calendar.html#last_day_of_year/2","title":"Cldr.Calendar.last_day_of_year/2","type":"function","doc":"Returns the last date of a year for a calendar. Arguments year is any year calendar is any module that implements the Calendar and Cldr.Calendar behaviours Returns a Date.t() or {:error, :invalid_date} Examples iex&gt; Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.Gregorian) %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 12, year: 2019} iex&gt; Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF) %Date{calendar: Cldr.Calendar.NRF, day: 7, month: 52, year: 2019}"},{"ref":"Cldr.Calendar.html#last_gregorian_day_of_year/1","title":"Cldr.Calendar.last_gregorian_day_of_year/1","type":"function","doc":""},{"ref":"Cldr.Calendar.html#last_gregorian_day_of_year/2","title":"Cldr.Calendar.last_gregorian_day_of_year/2","type":"function","doc":"Returns the gregorian date of the first day of a year for a calendar. Arguments year is any integer year number Examples iex&gt; Cldr.Calendar.last_gregorian_day_of_year 2019, Cldr.Calendar.Gregorian %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 12, year: 2019} iex&gt; Cldr.Calendar.last_gregorian_day_of_year 2019, Cldr.Calendar.NRF %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 2, year: 2020}"},{"ref":"Cldr.Calendar.html#localize/3","title":"Cldr.Calendar.localize/3","type":"function","doc":"Returns a localized string for a part of a Date.t. Arguments date_ is any Date.t part is one of :era, :quarter, :month, :day_of_week or :days_of_week options is a keyword list of options Options :locale is any valid locale name in the list returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2. The default is Cldr.get_locale(). backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. :format is one of :wide, :abbreviated or :narrow. The default is :abbreviated. Returns A string representing the localized date part, or A list of strings representing the days of the week for the part :days_of_week. The days are in week order for the given date&#39;s calendar {error, {exception_module, message}} if an error is detected Examples iex&gt; Cldr.Calendar.localize ~D[2019-01-01], :era &quot;AD&quot; iex&gt; Cldr.Calendar.localize ~D[2019-01-01], :day_of_week &quot;Tue&quot; iex&gt; Cldr.Calendar.localize ~D[0001-01-01], :day_of_week &quot;Mon&quot; iex&gt; Cldr.Calendar.localize ~D[2019-01-01], :days_of_week [{1, &quot;Mon&quot;}, {2, &quot;Tue&quot;}, {3, &quot;Wed&quot;}, {4, &quot;Thu&quot;}, {5, &quot;Fri&quot;}, {6, &quot;Sat&quot;}, {7, &quot;Sun&quot;}] iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :era &quot;AD&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :quarter &quot;Q2&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :month &quot;Jun&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week &quot;Sat&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :wide &quot;Saturday&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :narrow &quot;S&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, locale: &quot;ar&quot; &quot;السبت&quot;"},{"ref":"Cldr.Calendar.html#minus/4","title":"Cldr.Calendar.minus/4","type":"function","doc":"Decrements a date or date range by an integer amount of a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year, :quarter, :month, :week or :day options is a Kwyrod list of options Options :coerce is a boolean which, when set to true will coerce the month and/or day to be a valid date. This affects,for example, moving to the previous month from ~D[2019-03-31]. Sincce there is no date ~D[2019-02-31] this would normally return {:error, :invalid_date}. Setting coerce: true it will return ~D[2019-02-28]. Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples iex&gt; import Cldr.Calendar.Sigils iex&gt; Cldr.Calendar.minus ~d[2016-03-01], :days, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 29, month: 2, year: 2016} iex&gt; Cldr.Calendar.minus ~d[2019-03-01], :months, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 2, year: 2019} iex&gt; Cldr.Calendar.minus ~d[2016-03-01], :days, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 29, month: 2, year: 2016} iex&gt; Cldr.Calendar.minus ~d[2019-03-01], :days, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019} iex&gt; Cldr.Calendar.minus ~d[2019-03-01], :months, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 2, year: 2019} iex&gt; Cldr.Calendar.minus ~d[2019-03-01], :quarters, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 12, year: 2018} iex&gt; Cldr.Calendar.minus ~d[2019-03-01], :years, 1 %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 3, year: 2018}"},{"ref":"Cldr.Calendar.html#modified_julian_day/1","title":"Cldr.Calendar.modified_julian_day/1","type":"function","doc":"Returns the Modified Julian Day of a Date.t. Arguments date is any Date.t() Returns an integer number representing the Modified Julian Day of the date Notes The Modified Julian Day is the number of days since November 17, 1858. Therefore this function only returns valid values for dates after this date. Examples iex&gt; Cldr.Calendar.modified_julian_day ~D[2019-01-01] 58484"},{"ref":"Cldr.Calendar.html#monday/0","title":"Cldr.Calendar.monday/0","type":"function","doc":"Returns the ordinal day number representing Monday"},{"ref":"Cldr.Calendar.html#c:month/2","title":"Cldr.Calendar.month/2","type":"callback","doc":"Returns a date range representing the days in a given month for a calendar year."},{"ref":"Cldr.Calendar.html#month_of_year/1","title":"Cldr.Calendar.month_of_year/1","type":"function","doc":"Returns the month number for a date. Arguments date is any Date.t() Returns a the quarter of the year as an integer Examples iex&gt; import Cldr.Calendar.Sigils iex&gt; Cldr.Calendar.month_of_year ~d[2019-01-01] 1 iex&gt; Cldr.Calendar.month_of_year ~d[2019-12-01] 12 iex&gt; Cldr.Calendar.month_of_year ~d[2019-52-01]NRF 12 iex&gt; Cldr.Calendar.month_of_year ~d[2019-26-01]NRF 6"},{"ref":"Cldr.Calendar.html#c:month_of_year/3","title":"Cldr.Calendar.month_of_year/3","type":"callback","doc":"Returns the month for a given year, month or week, and day for a a calendar. The month_in_year is calculated based upon the calendar configuration."},{"ref":"Cldr.Calendar.html#months_in_year/1","title":"Cldr.Calendar.months_in_year/1","type":"function","doc":"See Date.months_in_year/1."},{"ref":"Cldr.Calendar.html#new/3","title":"Cldr.Calendar.new/3","type":"function","doc":"Creates a new calendar based upon the provided configuration. If a module exists with the calendar_module name then it is returned, not recreated. Arguments calendar_module is am atom representing the module name of the created calendar. calendar_type is an atom of either :month or :week indicating whcih type of calendar is to be created config is a keyword list defining the configuration of the calendar. Returns {:ok, module} where module is the new calendar module that conforms to the Calendar and Cldr.Calendar behaviours Configuration"},{"ref":"Cldr.Calendar.html#next/3","title":"Cldr.Calendar.next/3","type":"function","doc":"Returns the next date or date range for a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year, :quarter, :month, :week or :day Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples"},{"ref":"Cldr.Calendar.html#plus/2","title":"Cldr.Calendar.plus/2","type":"function","doc":"Increments a date or date range by an integer amount of a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year, :quarter, :month, :week or :day options is a Kwyrod list of options Options :coerce is a boolean which, when set to true will coerce the month and/or day to be a valid date. This affects,for example, moving to the previous month from ~D[2019-03-31]. Sincce there is no date ~D[2019-02-31] this would normally return {:error, :invalid_date}. Setting coerce: true it will return ~D[2019-02-28]. Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples"},{"ref":"Cldr.Calendar.html#plus/4","title":"Cldr.Calendar.plus/4","type":"function","doc":""},{"ref":"Cldr.Calendar.html#c:plus/6","title":"Cldr.Calendar.plus/6","type":"callback","doc":"Increments a Date.t or Date.Range.t by a specified positive or negative integer number of periods (year, quarter, month, week or day). Calendars need only implement this callback for :months and :quarters since all other date periods can be derived."},{"ref":"Cldr.Calendar.html#previous/3","title":"Cldr.Calendar.previous/3","type":"function","doc":"Returns the previous date or date range for a date period (year, quarter, month, week or day). Arguments date_or_date_range is any Date.t or Date.Range.t period is :year, :quarter, :month, :week or :day options is a Keyword list of options that is passed to plus/4 or minus/4 Returns When a Date.t is passed, a Date.t is returned. When a Date.Range.t is passed a Date.Range.t is returned. Examples"},{"ref":"Cldr.Calendar.html#c:quarter/2","title":"Cldr.Calendar.quarter/2","type":"callback","doc":"Returns a date range representing the days in a given quarter for a calendar year."},{"ref":"Cldr.Calendar.html#quarter_of_year/1","title":"Cldr.Calendar.quarter_of_year/1","type":"function","doc":"Returns the quarter number for a date. Arguments date is any Date.t() Returns a the quarter of the year as an integer Examples iex&gt; Cldr.Calendar.quarter_of_year ~D[2019-01-01] 1 iex&gt; Cldr.Calendar.quarter_of_year Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF) 1 iex&gt; Cldr.Calendar.quarter_of_year Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF) 4"},{"ref":"Cldr.Calendar.html#saturday/0","title":"Cldr.Calendar.saturday/0","type":"function","doc":"Returns the ordinal day number representing Saturday."},{"ref":"Cldr.Calendar.html#sunday/0","title":"Cldr.Calendar.sunday/0","type":"function","doc":"Returns the ordinal day number representing Sunday."},{"ref":"Cldr.Calendar.html#thursday/0","title":"Cldr.Calendar.thursday/0","type":"function","doc":"Returns the ordinal day number representing Thursday."},{"ref":"Cldr.Calendar.html#tuesday/0","title":"Cldr.Calendar.tuesday/0","type":"function","doc":"Returns the ordinal day number representing Tuesday."},{"ref":"Cldr.Calendar.html#wednesday/0","title":"Cldr.Calendar.wednesday/0","type":"function","doc":"Returns the ordinal day number representing Wednesday."},{"ref":"Cldr.Calendar.html#c:week/2","title":"Cldr.Calendar.week/2","type":"callback","doc":"Returns a date range representing the days in a given week for a calendar year."},{"ref":"Cldr.Calendar.html#week_of_year/1","title":"Cldr.Calendar.week_of_year/1","type":"function","doc":"Returns the {year, week_number} for a date. Arguments date is any Date.t() Returns a the week of the year as an integer or {:error, :not_defined} if the calendar does not support the concept of weeks. Examples iex&gt; import Cldr.Calendar.Sigils iex&gt; Cldr.Calendar.week_of_year ~d[2019-01-01] {2019, 1} iex&gt; Cldr.Calendar.week_of_year ~d[2019-12-01] {2019, 48} iex&gt; Cldr.Calendar.week_of_year ~d[2019-52-01]NRF {2019, 52} iex&gt; Cldr.Calendar.week_of_year ~d[2019-26-01]NRF {2019, 26} iex&gt; Cldr.Calendar.week_of_year ~d[2019-12-01]Julian {:error, :not_defined}"},{"ref":"Cldr.Calendar.html#c:week_of_year/3","title":"Cldr.Calendar.week_of_year/3","type":"callback","doc":"Returns a tuple of {year, week_in_year} for a given year, month or week, and day for a a calendar. The week_in_year is calculated based upon the calendar configuration."},{"ref":"Cldr.Calendar.html#weekday?/2","title":"Cldr.Calendar.weekday?/2","type":"function","doc":"Returns whether a given date is a weekday. Weekdays are locale-specific and depend on the policies of a given territory (country). Arguments date is any Date.t() options is a keyword list of options Options :locale is any locale or locale name validated by Cldr.validate_locale/2. The default is Cldr.get_locale() which returns the locale set for the current process :territory is any valid ISO-3166-2 territory that is validated by Cldr.validate_territory/1 :backend is any Cldr backend module. See the backend configuration documentation for further information. The default is Cldr.Calendar.Backend.Default which configures only the en locale. Notes When identifying which territory context within which to determine whether a given day is a weekday or not the following order applies: A territory specified by the :territory option The territory defined as part of the :locale option The territory defined as part of the current processes default locale. Examples # The defalt locale for [`Cldr`](https://hexdocs.pm/ex_cldr/2.7.0/Cldr.html) is `en-001` for which # the territory is `001` (the world). The weekdays # for `001` are Monday to Friday iex&gt; Cldr.Calendar.weekday? ~D[2019-03-23], locale: &quot;en&quot; false iex&gt; Cldr.Calendar.weekday? ~D[2019-03-23], territory: &quot;IS&quot; false # Saturday is a weekday in India iex&gt; Cldr.Calendar.weekday? ~D[2019-03-23], locale: &quot;en-IN&quot;, backend: MyApp.Cldr true # Friday is not a weekday in Saudi Arabia iex&gt; Cldr.Calendar.weekday? ~D[2019-03-22], locale: &quot;ar-SA&quot;, backend: MyApp.Cldr false # Friday is not a weekday in Israel iex&gt; Cldr.Calendar.weekday? ~D[2019-03-22], locale: &quot;he&quot;, backend: MyApp.Cldr false"},{"ref":"Cldr.Calendar.html#weekdays/1","title":"Cldr.Calendar.weekdays/1","type":"function","doc":"Returns a list of the days of the week that are considered a weekend for a given territory (country) Arguments territory is any valid ISO3166-2 code Returns A list of integers representing the days of the week that are week days Notes The list of days may not my monotonic. See the example for Saudi Arabia below. Examples iex&gt; Cldr.Calendar.weekdays(&quot;US&quot;) [1, 2, 3, 4, 5] iex&gt; Cldr.Calendar.weekdays(&quot;IN&quot;) [1, 2, 3, 4, 5, 6] iex&gt; Cldr.Calendar.weekdays(&quot;SA&quot;) [1, 2, 3, 4, 7] iex&gt; Cldr.Calendar.weekdays(&quot;xx&quot;) {:error, {Cldr.UnknownTerritoryError, &quot;The territory \\&quot;xx\\&quot; is unknown&quot;}}"},{"ref":"Cldr.Calendar.html#weekend/1","title":"Cldr.Calendar.weekend/1","type":"function","doc":"Returns a list of the days of the week that are considered a weekend for a given territory (country) Arguments territory is any valid ISO3166-2 code Returns A list of integers representing the days of the week that are weekend days Examples iex&gt; Cldr.Calendar.weekend(&quot;US&quot;) [6, 7] iex&gt; Cldr.Calendar.weekend(&quot;IN&quot;) [7] iex&gt; Cldr.Calendar.weekend(&quot;SA&quot;) [5, 6] iex&gt; Cldr.Calendar.weekend(&quot;xx&quot;) {:error, {Cldr.UnknownTerritoryError, &quot;The territory \\&quot;xx\\&quot; is unknown&quot;}}"},{"ref":"Cldr.Calendar.html#weekend?/2","title":"Cldr.Calendar.weekend?/2","type":"function","doc":"Returns whether a given date is a weekend day. Weekend days are locale-specific and depend on the policies of a given territory (country). Arguments date is any Date.t() options is a keyword list of options Options :locale is any locale or locale name validated by Cldr.validate_locale/2. The default is Cldr.get_locale() which returns the locale set for the current process :territory is any valid ISO-3166-2 territory that is validated by Cldr.validate_territory/1 :backend is any Cldr backend module. See the backend configuration documentation for further information. The default is Cldr.Calendar.Backend.Default which configures only the en locale. Notes When identifying which territory context within which to determine whether a given day is a weekend or not the following order applies: A territory specified by the :territory option The territory defined as part of the :locale option The territory defined as part of the current processes default locale. Examples # The defalt locale for [`Cldr`](https://hexdocs.pm/ex_cldr/2.7.0/Cldr.html) is `en-001` for which # the territory is `001` (the world). The weekend # for `001` is Saturday and Sunday iex&gt; Cldr.Calendar.weekend? ~D[2019-03-23] true iex&gt; Cldr.Calendar.weekend? ~D[2019-03-23], locale: &quot;en&quot; true iex&gt; Cldr.Calendar.weekend? ~D[2019-03-23], territory: &quot;IS&quot; true # In India the official weekend is only Sunday iex&gt; Cldr.Calendar.weekend? ~D[2019-03-23], locale: &quot;en-IN&quot;, backend: MyApp.Cldr false # In Israel the weekend starts on Friday iex&gt; Cldr.Calendar.weekend? ~D[2019-03-22], locale: &quot;he&quot;, backend: MyApp.Cldr true # As it also does in Saudia Arabia iex&gt; Cldr.Calendar.weekend? ~D[2019-03-22], locale: &quot;ar-SA&quot;, backend: MyApp.Cldr true # Sunday is not a weekend day in Saudi Arabia iex&gt; Cldr.Calendar.weekend? ~D[2019-03-24], locale: &quot;ar-SA&quot;, backend: MyApp.Cldr false"},{"ref":"Cldr.Calendar.html#weeks_to_days/1","title":"Cldr.Calendar.weeks_to_days/1","type":"function","doc":"Returns the number of days in n weeks Example iex&gt; Cldr.Calendar.weeks_to_days(2) 14"},{"ref":"Cldr.Calendar.html#c:year/1","title":"Cldr.Calendar.year/1","type":"callback","doc":"Returns a date range representing the days in a calendar year."},{"ref":"Cldr.Calendar.html#t:calendar/0","title":"Cldr.Calendar.calendar/0","type":"type","doc":"Specifies the type of a calendar. A calendar is a module that implements the Calendar and Cldr.Calendar behaviours."},{"ref":"Cldr.Calendar.html#t:calendar_type/0","title":"Cldr.Calendar.calendar_type/0","type":"type","doc":"Specifies the type of a calendar"},{"ref":"Cldr.Calendar.html#t:day_of_week/0","title":"Cldr.Calendar.day_of_week/0","type":"type","doc":"Specifies the days of the week as integers. Days of the week are encoded as the integers 1 through 7 with 1 representig Monday and 7 representing Sunday. Note that a calendar can be configured to start on any day of the week. day_of_week is only a way of encoding the days as an integer."},{"ref":"Cldr.Calendar.html#t:interval_relation/0","title":"Cldr.Calendar.interval_relation/0","type":"type","doc":"The types of relationship between two Date.Range intervals"},{"ref":"Cldr.Calendar.html#t:iso_day_number/0","title":"Cldr.Calendar.iso_day_number/0","type":"type","doc":"Represents the number of days since the calendar epoch. The Calendar epoch is 0000-01-01 in the proleptic gregorian calendar."},{"ref":"Cldr.Calendar.html#t:precision/0","title":"Cldr.Calendar.precision/0","type":"type","doc":"The precision for date intervals"},{"ref":"Cldr.Calendar.html#t:quarter/0","title":"Cldr.Calendar.quarter/0","type":"type","doc":"Specifies the quarter of year for a calendar date."},{"ref":"Cldr.Calendar.html#t:week/0","title":"Cldr.Calendar.week/0","type":"type","doc":"Specifies the week of year for a calendar date."},{"ref":"Cldr.Calendar.Config.html","title":"Cldr.Calendar.Config","type":"module","doc":"Defines the configuration for a calendar."},{"ref":"Cldr.Calendar.Config.html#t:t/0","title":"Cldr.Calendar.Config.t/0","type":"type","doc":"Defines the struct type for a calendar configuration"},{"ref":"Cldr.Calendar.FiscalYear.html","title":"Cldr.Calendar.FiscalYear","type":"module","doc":""},{"ref":"Cldr.Calendar.FiscalYear.html#calendar_for/1","title":"Cldr.Calendar.FiscalYear.calendar_for/1","type":"function","doc":""},{"ref":"Cldr.Calendar.FiscalYear.html#known_fiscal_calendars/0","title":"Cldr.Calendar.FiscalYear.known_fiscal_calendars/0","type":"function","doc":""},{"ref":"Cldr.Calendar.FiscalYear.html#known_fiscal_years/0","title":"Cldr.Calendar.FiscalYear.known_fiscal_years/0","type":"function","doc":""},{"ref":"Cldr.Calendar.Interval.html","title":"Cldr.Calendar.Interval","type":"module","doc":"Implements functions to return intervals and compare date intervals. In particular it provides functions which return an interval (as a Date.Range.t) for years, quarters, months, weeks and days."},{"ref":"Cldr.Calendar.Interval.html#compare/2","title":"Cldr.Calendar.Interval.compare/2","type":"function","doc":"Compare two date ranges. Uses Allen&#39;s Interval Algebra to return one of 13 different relationships: RelationConverse :precedes:preceded_by :meets:met_by :overlaps:overlapped_by :finished_by:finishes :contains:during :starts:started_by :equals:equals Arguments range_1 is a Date.Range.t range_2 is a Date.Range.t Returns An atom representing the relationship between the two ranges. Examples iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]), Cldr.Calendar.Interval.day(~D[2019-01-02]) :meets iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]), Cldr.Calendar.Interval.day(~D[2019-01-03]) :precedes iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-03]), Cldr.Calendar.Interval.day(~D[2019-01-01]) :preceded_by iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]), Cldr.Calendar.Interval.day(~D[2019-01-01]) :met_by iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]), Cldr.Calendar.Interval.day(~D[2019-01-02]) :equals"},{"ref":"Cldr.Calendar.Interval.html#day/1","title":"Cldr.Calendar.Interval.day/1","type":"function","doc":"Returns a Date.Range.t that represents the day. The range is enumerable. Arguments year is any year for calendar day is any day in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian. Returns A Date.Range.t() representing the the enumerable days in the week Examples iex&gt; Cldr.Calendar.Interval.day 2019, 52, Cldr.Calendar.US #DateRange&lt;%Date{calendar: Cldr.Calendar.US, day: 21, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.US, day: 21, month: 2, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.day 2019, 92, Cldr.Calendar.NRF #DateRange&lt;%Date{calendar: Cldr.Calendar.NRF, day: 1, month: 14, year: 2019}, %Date{calendar: Cldr.Calendar.NRF, day: 1, month: 14, year: 2019}&gt; Cldr.Calendar.Interval.day 2019, 8, Cldr.Calendar.ISOWeek #DateRange&lt;%Date{calendar: Cldr.Calendar.ISOWeek, day: 1, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.ISOWeek, day: 1, month: 2, year: 2019}&gt;"},{"ref":"Cldr.Calendar.Interval.html#day/3","title":"Cldr.Calendar.Interval.day/3","type":"function","doc":""},{"ref":"Cldr.Calendar.Interval.html#month/1","title":"Cldr.Calendar.Interval.month/1","type":"function","doc":"Returns a Date.Range.t that represents the year. The range is enumerable. Arguments year is any year for calendar month is any month in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian. Returns A Date.Range.t() representing the the enumerable days in the month Examples iex&gt; Cldr.Calendar.Interval.month 2019, 3, Cldr.Calendar.UK #DateRange&lt;%Date{calendar: Cldr.Calendar.UK, day: 1, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.UK, day: 30, month: 3, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.month 2019, 3, Cldr.Calendar.US #DateRange&lt;%Date{calendar: Cldr.Calendar.US, day: 1, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.US, day: 31, month: 3, year: 2019}&gt;"},{"ref":"Cldr.Calendar.Interval.html#month/3","title":"Cldr.Calendar.Interval.month/3","type":"function","doc":""},{"ref":"Cldr.Calendar.Interval.html#quarter/1","title":"Cldr.Calendar.Interval.quarter/1","type":"function","doc":"Returns a Date.Range.t that represents the quarter. The range is enumerable. Arguments year is any year for calendar quarter is any quarter in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian. Returns A Date.Range.t() representing the the enumerable days in the quarter Examples iex&gt; Cldr.Calendar.Interval.quarter 2019, 2, Cldr.Calendar.UK #DateRange&lt;%Date{calendar: Cldr.Calendar.UK, day: 1, month: 4, year: 2019}, %Date{calendar: Cldr.Calendar.UK, day: 30, month: 6, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.quarter 2019, 2, Cldr.Calendar.ISOWeek #DateRange&lt;%Date{calendar: Cldr.Calendar.ISOWeek, day: 1, month: 14, year: 2019}, %Date{calendar: Cldr.Calendar.ISOWeek, day: 7, month: 26, year: 2019}&gt;"},{"ref":"Cldr.Calendar.Interval.html#quarter/3","title":"Cldr.Calendar.Interval.quarter/3","type":"function","doc":""},{"ref":"Cldr.Calendar.Interval.html#week/1","title":"Cldr.Calendar.Interval.week/1","type":"function","doc":"Returns a Date.Range.t that represents the year. The range is enumerable. Arguments year is any year for calendar week is any week in the year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian. Returns A Date.Range.t() representing the the enumerable days in the week or {:error, :not_defined} if the calendar does not support the concept of weeks Examples iex&gt; Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.US #DateRange&lt;%Date{calendar: Cldr.Calendar.US, day: 22, month: 12, year: 2019}, %Date{calendar: Cldr.Calendar.US, day: 28, month: 12, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.NRF #DateRange&lt;%Date{calendar: Cldr.Calendar.NRF, day: 1, month: 52, year: 2019}, %Date{calendar: Cldr.Calendar.NRF, day: 7, month: 52, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.ISOWeek #DateRange&lt;%Date{calendar: Cldr.Calendar.ISOWeek, day: 1, month: 52, year: 2019}, %Date{calendar: Cldr.Calendar.ISOWeek, day: 7, month: 52, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.Julian {:error, :not_defined}"},{"ref":"Cldr.Calendar.Interval.html#week/3","title":"Cldr.Calendar.Interval.week/3","type":"function","doc":""},{"ref":"Cldr.Calendar.Interval.html#year/1","title":"Cldr.Calendar.Interval.year/1","type":"function","doc":"Returns a Date.Range.t that represents the year. The range is enumerable. Arguments year is any year for calendar calendar is any module that implements the Calendar and Cldr.Calendar behaviours. The default is Cldr.Calendar.Gregorian. Returns A Date.Range.t() representing the the enumerable days in the year Examples iex&gt; Cldr.Calendar.Interval.year 2019, Cldr.Calendar.UK #DateRange&lt;%Date{calendar: Cldr.Calendar.UK, day: 1, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.UK, day: 31, month: 12, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.year 2019, Cldr.Calendar.NRF #DateRange&lt;%Date{calendar: Cldr.Calendar.NRF, day: 1, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.NRF, day: 7, month: 52, year: 2019}&gt;"},{"ref":"Cldr.Calendar.Interval.html#year/2","title":"Cldr.Calendar.Interval.year/2","type":"function","doc":""},{"ref":"Cldr.Calendar.Julian.html","title":"Cldr.Calendar.Julian","type":"module","doc":""},{"ref":"Cldr.Calendar.Julian.html#calendar_base/0","title":"Cldr.Calendar.Julian.calendar_base/0","type":"function","doc":"Identifies that this calendar is month based."},{"ref":"Cldr.Calendar.Julian.html#cldr_calendar_type/0","title":"Cldr.Calendar.Julian.cldr_calendar_type/0","type":"function","doc":"Defines the CLDR calendar type for this calendar. This type is used in support of Cldr.Calendar.localize/3. Currently only :gregorian is supported."},{"ref":"Cldr.Calendar.Julian.html#date_from_iso_days/1","title":"Cldr.Calendar.Julian.date_from_iso_days/1","type":"function","doc":"Returns a {year, month, day} calculated from the number of iso_days."},{"ref":"Cldr.Calendar.Julian.html#date_to_iso_days/3","title":"Cldr.Calendar.Julian.date_to_iso_days/3","type":"function","doc":"Returns the number of days since the calendar epoch for a given year-month-day"},{"ref":"Cldr.Calendar.Julian.html#day_of_era/3","title":"Cldr.Calendar.Julian.day_of_era/3","type":"function","doc":"Calculates the day and era from the given year, month, and day."},{"ref":"Cldr.Calendar.Julian.html#day_of_week/3","title":"Cldr.Calendar.Julian.day_of_week/3","type":"function","doc":"Calculates the day of the week from the given year, month, and day. It is an integer from 1 to 7, where 1 is Monday and 7 is Sunday."},{"ref":"Cldr.Calendar.Julian.html#day_of_year/3","title":"Cldr.Calendar.Julian.day_of_year/3","type":"function","doc":"Calculates the day of the year from the given year, month, and day."},{"ref":"Cldr.Calendar.Julian.html#days_in_month/2","title":"Cldr.Calendar.Julian.days_in_month/2","type":"function","doc":"Returns how many days there are in the given year-month."},{"ref":"Cldr.Calendar.Julian.html#days_in_week/0","title":"Cldr.Calendar.Julian.days_in_week/0","type":"function","doc":"Returns the number days in a a week."},{"ref":"Cldr.Calendar.Julian.html#days_in_year/1","title":"Cldr.Calendar.Julian.days_in_year/1","type":"function","doc":"Returns the number days in a given year."},{"ref":"Cldr.Calendar.Julian.html#epoch/0","title":"Cldr.Calendar.Julian.epoch/0","type":"function","doc":""},{"ref":"Cldr.Calendar.Julian.html#iso_week_of_year/3","title":"Cldr.Calendar.Julian.iso_week_of_year/3","type":"function","doc":"Calculates the ISO week of the year from the given year, month, and day. It is an integer from 1 to 53."},{"ref":"Cldr.Calendar.Julian.html#leap_year?/1","title":"Cldr.Calendar.Julian.leap_year?/1","type":"function","doc":"Returns if the given year is a leap year."},{"ref":"Cldr.Calendar.Julian.html#month/2","title":"Cldr.Calendar.Julian.month/2","type":"function","doc":"Returns a Date.Range.t representing a given month of a year."},{"ref":"Cldr.Calendar.Julian.html#month_of_year/3","title":"Cldr.Calendar.Julian.month_of_year/3","type":"function","doc":"Calculates the month of the year from the given year, month, and day. It is an integer from 1 to 12."},{"ref":"Cldr.Calendar.Julian.html#naive_datetime_from_iso_days/1","title":"Cldr.Calendar.Julian.naive_datetime_from_iso_days/1","type":"function","doc":"Converts the Calendar.iso_days/0 format to the datetime format specified by this calendar."},{"ref":"Cldr.Calendar.Julian.html#naive_datetime_to_iso_days/7","title":"Cldr.Calendar.Julian.naive_datetime_to_iso_days/7","type":"function","doc":"Returns the Calendar.iso_days/0 format of the specified date."},{"ref":"Cldr.Calendar.Julian.html#periods_in_year/1","title":"Cldr.Calendar.Julian.periods_in_year/1","type":"function","doc":"Calculates the number of period in a given year. A period corresponds to a month in month-based calendars and a week in week-based calendars.."},{"ref":"Cldr.Calendar.Julian.html#plus/6","title":"Cldr.Calendar.Julian.plus/6","type":"function","doc":"Adds an increment number of date_parts to a year-month-day. date_part can be :quarters or:months."},{"ref":"Cldr.Calendar.Julian.html#quarter/2","title":"Cldr.Calendar.Julian.quarter/2","type":"function","doc":"Returns a Date.Range.t representing a given quarter of a year."},{"ref":"Cldr.Calendar.Julian.html#quarter_of_year/3","title":"Cldr.Calendar.Julian.quarter_of_year/3","type":"function","doc":"Calculates the quarter of the year from the given year, month, and day. It is an integer from 1 to 4."},{"ref":"Cldr.Calendar.Julian.html#valid_date?/3","title":"Cldr.Calendar.Julian.valid_date?/3","type":"function","doc":"Determines if the date given is valid according to this calendar."},{"ref":"Cldr.Calendar.Julian.html#week/2","title":"Cldr.Calendar.Julian.week/2","type":"function","doc":"Returns a Date.Range.t representing a given week of a year."},{"ref":"Cldr.Calendar.Julian.html#week_of_year/3","title":"Cldr.Calendar.Julian.week_of_year/3","type":"function","doc":"Calculates the week of the year from the given year, month, and day. It is an integer from 1 to 53."},{"ref":"Cldr.Calendar.Julian.html#year/1","title":"Cldr.Calendar.Julian.year/1","type":"function","doc":"Returns a Date.Range.t representing a given year."},{"ref":"Cldr.Calendar.Julian.html#year_of_era/1","title":"Cldr.Calendar.Julian.year_of_era/1","type":"function","doc":"Calculates the year and era from the given year. The ISO calendar has two eras: the current era which starts in year 1 and is defined as era &quot;1&quot;. And a second era for those years less than 1 defined as era &quot;0&quot;."},{"ref":"Cldr.Calendar.Julian.html#t:day/0","title":"Cldr.Calendar.Julian.day/0","type":"type","doc":""},{"ref":"Cldr.Calendar.Julian.html#t:month/0","title":"Cldr.Calendar.Julian.month/0","type":"type","doc":""},{"ref":"Cldr.Calendar.Julian.html#t:year/0","title":"Cldr.Calendar.Julian.year/0","type":"type","doc":""},{"ref":"Cldr.Calendar.Kday.html","title":"Cldr.Calendar.Kday","type":"module","doc":"Provide K-Day functions for Dates, DateTimes and NaiveDateTimes."},{"ref":"Cldr.Calendar.Kday.html#first_kday/2","title":"Cldr.Calendar.Kday.first_kday/2","type":"function","doc":"Return the date of the first day_of_week on or after the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or ISO days k is an integer day of the week. Returns A %Date{”} in the calendar of the date provided as an argument Examples # US election day iex&gt; Cldr.Calendar.Kday.first_kday(~D[2017-11-02], 2) ~D[2017-11-07] # US Daylight savings end iex&gt; Cldr.Calendar.Kday.first_kday(~D[2017-11-01], 7) ~D[2017-11-05]"},{"ref":"Cldr.Calendar.Kday.html#kday_after/2","title":"Cldr.Calendar.Kday.kday_after/2","type":"function","doc":"Return the date of the day_of_week after the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday.kday_after(~D[2016-02-29], 2) ~D[2016-03-01] iex&gt; Cldr.Calendar.Kday.kday_after(~D[2017-11-30], 1) ~D[2017-12-04] iex&gt; Cldr.Calendar.Kday.kday_after(~D[2017-06-30], 6) ~D[2017-07-01]"},{"ref":"Cldr.Calendar.Kday.html#kday_before/2","title":"Cldr.Calendar.Kday.kday_before/2","type":"function","doc":"Return the date of the day_of_week before the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday.kday_before(~D[2016-02-29], 2) ~D[2016-02-23] iex&gt; Cldr.Calendar.Kday.kday_before(~D[2017-11-30], 1) ~D[2017-11-27] # 6 means Saturday. Use either the integer value or the atom form. iex&gt; Cldr.Calendar.Kday.kday_before(~D[2017-06-30], 6) ~D[2017-06-24]"},{"ref":"Cldr.Calendar.Kday.html#kday_nearest/2","title":"Cldr.Calendar.Kday.kday_nearest/2","type":"function","doc":"Return the date of the day_of_week nearest the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday.kday_nearest(~D[2016-02-29], 2) ~D[2016-03-01] iex&gt; Cldr.Calendar.Kday.kday_nearest(~D[2017-11-30], 1) ~D[2017-11-27] iex&gt; Cldr.Calendar.Kday.kday_nearest(~D[2017-06-30], 6) ~D[2017-07-01]"},{"ref":"Cldr.Calendar.Kday.html#kday_on_or_after/2","title":"Cldr.Calendar.Kday.kday_on_or_after/2","type":"function","doc":"Return the date of the day_of_week on or after the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday.kday_on_or_after(~D[2016-02-29], 2) ~D[2016-03-01] iex&gt; Cldr.Calendar.Kday.kday_on_or_after(~D[2017-11-30], 1) ~D[2017-12-04] iex&gt; Cldr.Calendar.Kday.kday_on_or_after(~D[2017-06-30], 6) ~D[2017-07-01]"},{"ref":"Cldr.Calendar.Kday.html#kday_on_or_before/2","title":"Cldr.Calendar.Kday.kday_on_or_before/2","type":"function","doc":"Return the date of the day_of_week on or before the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples iex&gt; Cldr.Calendar.Kday.kday_on_or_before(~D[2016-02-29], 2) ~D[2016-02-23] iex&gt; Cldr.Calendar.Kday.kday_on_or_before(~D[2017-11-30], 1) ~D[2017-11-27] iex&gt; Cldr.Calendar.Kday.kday_on_or_before(~D[2017-06-30], 6) ~D[2017-06-24]"},{"ref":"Cldr.Calendar.Kday.html#last_kday/2","title":"Cldr.Calendar.Kday.last_kday/2","type":"function","doc":"Return the date of the last day_of_week on or before the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Example # Memorial Day in the US iex&gt; Cldr.Calendar.Kday.last_kday(~D[2017-05-31], 1) ~D[2017-05-29]"},{"ref":"Cldr.Calendar.Kday.html#nth_kday/3","title":"Cldr.Calendar.Kday.nth_kday/3","type":"function","doc":"Return the date of the nth day_of_week on or before/after the specified date. Arguments date is %Date{}, a %DateTime{}, %NaiveDateTime{} or a Rata Die n is the cardinal number of k before (negative n) or after (positive n) the specified date k is an integer day of the week. Returns A %Date{} in the calendar of the date provided as an argument Examples # Thanksgiving in the US iex&gt; Cldr.Calendar.Kday.nth_kday(~D[2017-11-01], 4, 4) ~D[2017-11-23] # Labor day in the US iex&gt; Cldr.Calendar.Kday.nth_kday(~D[2017-09-01], 1, 1) ~D[2017-09-04] # Daylight savings time starts in the US iex&gt; Cldr.Calendar.Kday.nth_kday(~D[2017-03-01], 2, 7) ~D[2017-03-12]"},{"ref":"readme.html","title":"Cldr Calendars","type":"extras","doc":"Cldr Calendars My wife&#39;s jealousy is getting ridiculous. The other day she looked at my calendar and wanted to know who May was. -- Rodney Dangerfield Calendars are curious things. For centuries people from all cultures have sought to impose human order on the astronomical movements of the earth and moon. Today, despite much of the world converting on the Gregorian calendar, there remain many derivative and alternative ways for humans to organize the passage of time. Cldr Calendars builds on Elixir&#39;s standard Calendar module to provide additional calendars and calendar functionality intended to be of practical use. In particular Cdlr Calendars: Provides support for configurable month-based and week-based calendars that are in common use as Fiscal Year calendars for countries and organizations around the world. See Cldr.Calendar.new/3 Supports localisation of common calendar terms such as day of the week and month of the year using the CLDR data that is available for over 500 locales. See Cldr.Calendar.localize/3 Supports locale-specific knowledge of what is a weekend or a workday. See Cldr.Calendar.weekend/1, Cldr.Calendar.weekend?/2, Cldr.Calendar.weekdays/1 and Cldr.Calendar.weekday?/2. Provides convenient Date.Range calculators for years, quarters, months and weeks for calendars and provides the means to move to the next and previous period in a calendar where a period may be a year, quarter, month, week or day. Supports adding or substracting periods to dates and date ranges. See Calendar.plus/3 and Calendar.minus/3 Includes pre-defined calendars for Gregorian (compatible with the builtin Calendar module), ISOWeek and National Retail Federation (NRF) calendars Includes functions to find the first, last, nearest and nth days of the week from a date. For example, find the 2nd Tuesday in November. See the documentation for Cldr.Calendar for the main public API and the functions contained therein."},{"ref":"readme.html#getting-started","title":"Cldr Calendars - Getting Started","type":"extras","doc":"Let&#39;s say you work for Cisco Systems. Your learn that the financial year ends on the last Saturday of July. To make things easy you&#39;d like to compare the results of this financial year to last finanical year. And you&#39;d like to know how many days are left this quarter in order to achieve your sales targets. Here&#39;s how we do that: Define a calendar that represents Cisco&#39;s financial year Each calendar is defined as a module that implements both the Calendar and Cldr.Calendar behaviours. The details of how that is achieved isn&#39;t important at this stage. Its easy to define your own calendar module through some configuration parameters. Here&#39;s how we do that for Cisco: defmodule Cldr.Calendar.CSCO do use Cldr.Calendar.Base.Week, first_or_last: :last, day: 6, month: 7 end This configuration says that the calendar is defined as first_or_last: :last which means we are defining a calendar in terms of when it ends (you can of course also define a calendar in terms of when it starts by setting this to :first). The :last day is Saturday, which is in Calendar speak, the sixth day of the week. Days of the week are numbered from 1 for Monday to 7 to Sunday. The :month is July. Months are numbered from January being 1 to December being 12. There we have it, a calendar that is based upon the definition of &quot;ends on the last Saturday of July&quot;. Dates in Cisco&#39;s calendar You might be wondering, how to we represent dates in a customised calendar like this? Thanks to the flexibility of Elixir&#39;s standard Calendar module, we can leverage existing functions to build a date. Lets build a date which is the first day of Cisco&#39;s financial year for 2019. {:ok, date} = Date.new(2019, 1, 1, Cldr.Calendar.CSCO) {:ok, %Date{calendar: Cldr.Calendar.CSCO, day: 1, month: 1, year: 2019}} That was easy. All dates are specified in the context of the specific calendar. We don&#39;t need to know what the equivalent Gregorian calendar date is. But we can find out if we want to: iex&gt; Date.convert date, Calendar.ISO {:ok, ~D[2018-07-29]} Which you will see is July 29th, 2018 - a Sunday. Since we specified that the :last day of the year is a Saturday this makes sense. You will also note that this is a date in 2018 as it should be. The year ends in July so it must start around 12 months earlier - in July of 2018. This would also mean that the last day of Fiscal Year 2018 must be July 28th, 2018. Lets check: iex&gt; Cldr.Calendar.last_gregorian_day_of_year(2018, Cldr.Calendar.CSCO) {:ok, %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 7, year: 2018}} Which you will see is the last Saturday in July for 2018. Years, quarters, months, weeks and days A common activity with calendars is selecting data in certain date ranges or iterating over those same ranges. Cldr Calendars makes that easy. Want to know what is the first quarter of Cisco&#39;s financial year in 2019? iex&gt; range = Cldr.Calendar.quarter 2019, 1, Cldr.Calendar.CSCO #DateRange&lt;%Date{calendar: Cldr.Calendar.CSCO, day: 1, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.CSCO, day: 7, month: 13, year: 2019}&gt; A Date.Range.t is returned which can be enumerated with any of Elixir&#39;s Enum or Stream functions. The same applies for year, month, week and day. Let&#39;s list all of the days Cisco&#39;s first quarter: iex&gt; Enum.map range, &amp;Cldr.Calendar.date_to_string/1 [&quot;2019-W01-1&quot;, &quot;2019-W01-2&quot;, &quot;2019-W01-3&quot;, &quot;2019-W01-4&quot;, &quot;2019-W01-5&quot;, &quot;2019-W01-6&quot;, &quot;2019-W01-7&quot;, &quot;2019-W02-1&quot;, &quot;2019-W02-2&quot;, &quot;2019-W02-3&quot;, &quot;2019-W02-4&quot;, &quot;2019-W02-5&quot;, &quot;2019-W02-6&quot;, &quot;2019-W02-7&quot;, &quot;2019-W03-1&quot;, &quot;2019-W03-2&quot;, &quot;2019-W03-3&quot;, &quot;2019-W03-4&quot;, &quot;2019-W03-5&quot;, &quot;2019-W03-6&quot;, &quot;2019-W03-7&quot;, &quot;2019-W04-1&quot;, &quot;2019-W04-2&quot;, &quot;2019-W04-3&quot;, &quot;2019-W04-4&quot;, &quot;2019-W04-5&quot;, &quot;2019-W04-6&quot;, &quot;2019-W04-7&quot;, &quot;2019-W05-1&quot;, &quot;2019-W05-2&quot;, &quot;2019-W05-3&quot;, &quot;2019-W05-4&quot;, &quot;2019-W05-5&quot;, &quot;2019-W05-6&quot;, &quot;2019-W05-7&quot;, &quot;2019-W06-1&quot;, &quot;2019-W06-2&quot;, &quot;2019-W06-3&quot;, &quot;2019-W06-4&quot;, &quot;2019-W06-5&quot;, &quot;2019-W06-6&quot;, &quot;2019-W06-7&quot;, &quot;2019-W07-1&quot;, &quot;2019-W07-2&quot;, &quot;2019-W07-3&quot;, &quot;2019-W07-4&quot;, &quot;2019-W07-5&quot;, &quot;2019-W07-6&quot;, &quot;2019-W07-7&quot;, &quot;2019-W08-1&quot;, ...] But wait a minute, these don&#39;t look like familiar dates! Shouldn&#39;t they be formatted as &quot;yyy-mm-dd&quot;? The answer in this case is &quot;no&quot;. If you look carefully at where we asked for the date range for Cisco&#39;s first quarter of 2019 you will see %Date{calendar: Cldr.Calendar.CSCO, day: 7, month: 13, year: 2019} as the last date in the range. There is, of course, no such month as 13 in the Gregorian calendar. What&#39;s going on?"},{"ref":"readme.html#week-based-calendars","title":"Cldr Calendars - Week-based calendars","type":"extras","doc":"Cisco&#39;s calendar is an example of a &quot;week-based&quot; calendar. Such week-based calendars are examples of fiscal year calendars. In Cldr Calendar, any calendar that is defined in terms of &quot;[first | last] [day] of [month]&quot; is a week-based calendar. These calendars have a year of 52 weeks duration except in &quot;leap years&quot; that have 53 weeks. The most well-known week-based calendar may be the ISO Week Calendar. How would we define that calendar in Cldr Calendars? Easy! defmodule Cldr.Calendar.ISOWeek do use Cldr.Calendar.Base.Week, day: 1, min_days: 4 end This says that the calendar starts on the first Monday in January. How do we know that? It&#39;s because :month defaults to 1 (January) and :first_or_last defaults to :first. Lets see what the first day of 2019 is in the ISOWeek calendar. iex&gt; date = Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.ISOWeek) %Date{calendar: Cldr.Calendar.ISOWeek, day: 1, month: 1, year: 2019} As expected, the date is expressed in terms of the calendar Cldr.Calendar.ISOWeek. What&#39;s the equivalent Gregorian day? iex&gt; Date.convert(date, Calendar.ISO) {:ok, ~D[2018-12-31]} That&#39;s interesting. The first day of the 2019 year in the ISO Week calendar is actually December 31st, 2018. Why is that? Week-based calendars can start or end on a given day of the week in a given month. But there is a third option: the given day of the week nearest to the start or end of the given month. This is indicated by the configuration parameter :min_days. For the ISO Week calendar we have min_days: 4. That means that at least 4 days of the first or last week have to be in the specified :month and then we select the nearest day of the week. Hence it is possible and even common for the gregorian start of the year for a week-based calendar to be up to 6 days before or after the Gregorian start of the year. Whats the last week of 2019 in the ISO Week calendar? iex&gt; date = Cldr.Calendar.week(2019, 52, Cldr.Calendar.ISOWeek) #DateRange&lt;%Date{calendar: Cldr.Calendar.ISOWeek, day: 1, month: 52, year: 2019}, %Date{calendar: Cldr.Calendar.ISOWeek, day: 7, month: 52, year: 2019}&gt; You&#39;ll see that for week-based calendars the date is actually stored as year, week, day where the :month field of the Date.t is actually the week in the year and :day is the day in the week."},{"ref":"readme.html#month-based-calendars","title":"Cldr Calendars - Month-based calendars","type":"extras","doc":"The Gregorian calendar is the canonical example of a month-based calendar. It starts on January 1st and ends on December 31st each year. But not all calendars start in January and end in December. The United States fiscal year starts on October 1st and ends on September 30th The United Kingdom fiscal year starts on April 1st and ends on March 31st The Australian fiscal year starts on July 1st and ends on June 30th Cldr Calendars allows month-based calendars to be defined based upon the first or last gregorian month of the year for that calendar. Of course sometimes we also want to refer to weeks within a year although this is less common than refering to days within months. Nevertheless, a month-based calendar can also take advantage of :first_day and :min_days to determine how to calculate weeks for month-based calendars too. Here&#39;s how we define each of the three example calendars above: defmodule Cldr.Calendar.US do use Cldr.Calendar.Base.Month, month: 10, min_days: 4, # The first week of the year is that with at least 4 days of October in it first_day: 7 # When referring to weeks, Sunday is the first day end defmodule Cldr.Calendar.UK do use Cldr.Calendar.Base.Month, month: 4 # The fiscal year starts in April end defmodule Cldr.Calendar.AU do use Cldr.Calendar.Base.Month, month: 7, # The fiscal year starts in July year: :ending # A year refers to the ending Gregorian year. # In this example, the Australian fiscal # year 2017 is the year that starts in July # 2016 and ends in June 2017 end"},{"ref":"readme.html#beginning-and-ending-gregorian-years","title":"Cldr Calendars - Beginning and ending gregorian years","type":"extras","doc":"When we talk about the Gregorian calendar we refer to the 12 months from January to December. However when we consider the various fiscal calendars, the Gregorian starting date and the Gregorian ending date will often be in different years. In these cases, when we say &quot;the 2019 US Fiscal Year&quot; what does that mean? The US fiscal year starts in October. Now we need to know whether refering to the &quot;the 2019 US Fiscal Year&quot; means the year that ends in September 2019 or the year that starts in October 2019. Some further examples are: The UK Fiscal Year starts in April. By convention, the Fiscal Year is the year that starts with April. The US Fiscal Year starts in October. By convention , the Fiscal Year is the year that has the ending October in it. The Australian Fiscal Year starts in July. By convention, the Fiscal Year is the year that ends in July. The National Retail Federation has a calendar that starts on the Saturday nearest the end of January. By convention, the Fiscal Year is the year of the starting Saturday. To cater for these varying definitions of what a Fiscal Year means, a configuration option :year can be set to :majority (which is the default), :beginning and :ending. :majority means that the Fiscal Year is the year that has the most Gregorian months in it. This is the default. :beginning means that the Fiscal Year is the year in which the first Gregorian month is found. :ending means that the Fiscal Year is the year in which the last Gregorian month is found. First lets consider the default :majority strategy. This strategy says that the Fiscal Year is that year in which the majority of Gregorian months are found. 2018 2019 2020 J F M A M J J A S O N D | J F M A M J J A S O N D | J F M A M J J A S O N D | . . . . . . . . . . . . | . . . . . . . . . . . . | . . . . . . . . . . . . | Majority Starts Jan &lt;---------------------&gt; Starts Mar &lt;-----------------------&gt; Starts Jun &lt;-----------------------&gt; Starts Jul &lt;-----------------------&gt; Starts Oct &lt;-----------------------&gt; Ends Dec &lt;---------------------&gt; Ends Feb &lt;-----------------------&gt; Ends May &lt;-----------------------&gt; Ends Jun &lt;-----------------------&gt; Ends Aug &lt;-----------------------&gt; From the diagram above we can define the following rules: For :starts calendars, we can say that the starting gregorian year is is the same as the fiscal year if the starting month is January through June inclusive. If the starting month is July through to December then the starting Gregorian year is the year prior to the fiscal year. Similarly, the ending Gregorian year is the next year for calendars that start in February through June and it&#39;s the fiscal year for calendars that start in July through December. Years that start in January end in January of the same year. For &quot;:ends&quot; calendars ....."},{"ref":"readme.html#calendar-creation","title":"Cldr Calendars - Calendar Creation","type":"extras","doc":"Since calendars defined in Cldr.Calendar are intended to be compatible and converible to other Calendars supporting Elixir&#39;s Calendar behaviour, the configuration of calendars needs to be encapsulated. The simplest way to is to define a module that uses either Cldr.Calendar.Base.Week or Cldr.Calendar.Base.Month. This is how we have been defining calendar modules in the examples so far. A calendar module can also be created at run time. It is semantically identical to defining a static module but the module is built at run time rather than compile time. New calendars are created with the function Cldr.Calendar.new/3. For example: iex&gt; Cldr.Calendar.new :my_new_calendar, :week, first_or_last: :first, first_day: 1, min_days: 7 {:ok, :my_new_calendar} Calendar functions are now available on the module :my_new_calendar. iex&gt; :my_new_calendar. __config__/0 date_from_iso_days/1 date_to_iso_days/3 date_to_string/3 datetime_to_string/11 day_of_era/3 day_of_week/3 day_of_year/3 ... Fiscal Calendars for Territories Cldr Calendars can create a fiscal year calendar for many territories (countries) based upon data from the CIA world fact book. To create a fiscal year calendar for a territory use the Cldr.Calendar.FiscalYear/1 function. iex&gt; Cldr.Calendar.FiscalYear.calendar_for(&quot;IS&quot;) {:ok, Cldr.Calendar.FiscalYear.IS} iex&gt; Cldr.Calendar.FiscalYear.calendar_for(&quot;ZZ&quot;) {:error, {Cldr.UnknownTerritoryError, &quot;The territory \\&quot;ZZ\\&quot; is unknown&quot;}} iex&gt; Cldr.Calendar.FiscalYear.calendar_for(:AF) {:error, {Cldr.UnknownCalendarError, &quot;Fiscal calendar is unknown for :AF&quot;}}"},{"ref":"readme.html#sigil-d","title":"Cldr Calendars - Sigil ~d","type":"extras","doc":"Cldr Calendars provides a convenince sigil for the creation of dates in calendars. Note that it is necessary to import the Cldr.Calendar.Sigils module before using the ~d sigil. iex&gt; import Cldr.Calendar.Sigils # Create a date in the default Cldr.Calendar.Gregorian iex&gt; ~d[2019-01-01] %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 1, year: 2019} # Inbuilt calendars can be referred to by their shortened form iex&gt; ~d[2019-01-01]NRF %Date{calendar: Cldr.Calendar.NRF, day: 1, month: 1, year: 2019} # Create a calendar and define a date in it iex&gt; Cldr.Calendar.new FiscalAU, :month, month: 7 {:ok, FiscalAU} iex&gt; iex(21)&gt; ~d[2019-01-01]FiscalAU %Date{calendar: FiscalAU, day: 1, month: 1, year: 2019}"},{"ref":"readme.html#date-localization","title":"Cldr Calendars - Date localization","type":"extras","doc":"Cldr Calendars is able to localize parts of a date include the era, quarter, month and day_of_week. The CLDR provides the underlying data. The function Cldr.Calendar.localize/3 provides the required functionality. Some examples are: iex&gt; Cldr.Calendar.localize ~D[2019-01-01], :era &quot;AD&quot; iex&gt; Cldr.Calendar.localize ~D[2019-01-01], :day_of_week &quot;Tue&quot; iex&gt; Cldr.Calendar.localize ~D[0001-01-01], :day_of_week &quot;Mon&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :era &quot;AD&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :quarter &quot;Q2&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :month &quot;Jun&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week &quot;Sat&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :wide &quot;Saturday&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :narrow &quot;S&quot; iex&gt; Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, locale: &quot;ar&quot; &quot;السبت&quot;"},{"ref":"readme.html#calendar-intervals-date-ranges","title":"Cldr Calendars - Calendar Intervals (date ranges)","type":"extras","doc":"Intervals representing parts of a calendar can be created and compared. Since intervals are represented as a Date.Range they can also be enumerated with the Map and Stream functions. Intervals can be created for a year, quarter, month, week and day. For example: iex&gt; Cldr.Calendar.Interval.year(2019) #DateRange&lt;%Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 12, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.month(2019, 3) #DateRange&lt;%Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.month(2019, 3, Cldr.Calendar.NRF) #DateRange&lt;%Date{calendar: Cldr.Calendar.NRF, day: 1, month: 10, year: 2019}, %Date{calendar: Cldr.Calendar.NRF, day: 7, month: 13, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.week(2019, 5, Cldr.Calendar.NRF) #DateRange&lt;%Date{calendar: Cldr.Calendar.NRF, day: 1, month: 5, year: 2019}, %Date{calendar: Cldr.Calendar.NRF, day: 7, month: 5, year: 2019}&gt; iex&gt; Cldr.Calendar.Interval.quarter(2019, 3) #DateRange&lt;%Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 7, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 9, year: 2019}&gt; Comparing Calendar Intervals Intervals can also be compared to each other and using the taxonomy of Allen&#39;s Interval Algebra a comparison will return one of 13 different relationship types between two calendar intervals: RelationConverse :precedes:preceded_by :meets:met_by :overlaps:overlapped_by :finished_by:finishes :contains:during :starts:started_by :equals:equals Some examples: iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]), Cldr.Calendar.Interval.day(~D[2019-01-02]) :meets iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]), Cldr.Calendar.Interval.day(~D[2019-01-03]) :precedes iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-03]), Cldr.Calendar.Interval.day(~D[2019-01-01]) :preceded_by iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]), Cldr.Calendar.Interval.day(~D[2019-01-01]) :met_by iex&gt; Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]), Cldr.Calendar.Interval.day(~D[2019-01-02]) :equals Configuring a Cldr backend for localization In order to localize date parts abackend module must be defined. This is a module which hosts the CLDR data for a set of locales. The detailed information for configuring a backend is documented here. For a simple configuration the following steps may be used: Create a backend module. defmodule MyApp.Cldr do use Cldr, locales: [&quot;en&quot;, &quot;fr&quot;, &quot;jp&quot;, &quot;ar&quot;] end Optionally configure this backend as the system default in your config.exs. config :ex_cldr, default_backend: MyApp.Cldr When creating a calendar a default backend may also be defined for this calendar. defmodule MyCalendar do use Cldr.Calendar.Base.Month, month: 4, cldr_backend: MyApp.Cldr end It is also possible to pass the name of a backend module to the Cldr.Calendar.localize/3 function by specifying the :backend option with a backend module name."},{"ref":"readme.html#cldr-calendars-installation","title":"Cldr Calendars - Cldr Calendars Installation","type":"extras","doc":"Add ex_cldr_calendars to your deps in mix.exs. def deps do [ {:ex_cldr_calendars, &quot;~&gt; 0.1&quot;} ... ] end To Do [ ] Implement hybrid base calendar. This is a week-based calendar that presents dates in a monthly format. Symmetry454 is an example. [ ] Add week_of_month to callbacks calendars"},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2018-2019 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Cldr Calendars v0.8.0","type":"extras","doc":"Changelog for Cldr Calendars v0.8.0 This is the changelog for Cldr v0.8.0 released on June 8th, 2019. For older changelogs please consult the release tag on GitHub"},{"ref":"changelog.html#enhancements","title":"Changelog for Cldr Calendars v0.8.0 - Enhancements","type":"extras","doc":"Adds option :type to Cldr.Calendar.localize/3. This determines the format type to be localized. The valid types are :format (the default) or :stand_alone. Add Cldr.Calendar.day_periods/2 to support localization of the day periods of a time Add Cldr.Calendar.default_calendar/0. Returns Cldr.Calendar.Gregorian Add Cldr.Calendar.default_cldr_calendar/0. Returns :gregorian Changelog for Cldr Calendars v0.7.0 This is the changelog for Cldr v0.7.0 released on June 1st, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes Moved year/1, quarter/1, month/1, week/1 and day/1 to a new module Cldr.Calendar.Interval Enhancements Adds Cldr.Calendar.Interval.compare/2 to compare two intervals (date ranges) using Allen&#39;s Interval Algebra taxonomy. Defaults the calendar to Cldr.Calendar.Gregorian for Cldr.Calendar.Interval.year/2, Cldr.Calendar.Interval.quarter/3, Cldr.Calendar.Interval.month/3, Cldr.Calendar.Interval.week/3 and Cldr.Calendar.Interval.day/3 Changelog for Cldr Calendars v0.6.0 This is the changelog for Cldr v0.6.0 released on April 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Remove the need for nimble_csv as a dependency Changelog for Cldr Calendars v0.5.0 This is the changelog for Cldr v0.5.0 released on April 21th, 2019. For older changelogs please consult the release tag on GitHub Breaking changes Cldr.Calendar.localize/3 for :days_of_week now returns a list of 2-tuples that are of the format {day_of_week, day_name}. Enhancements Add Cldr.Calendar.localize/6 which localises numbers as part of a date without parameter checking. This is considered a private implementation for now. Changelog for Cldr Calendars v0.4.1 This is the changelog for Cldr v0.4.1 released on April 19th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix calculation of days_in_month for the last month in long year of a week-based calendar Changelog for Cldr Calendars v0.4.0 This is the changelog for Cldr v0.4.0 released on April 19th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Calendar.interval_stream/3 which returns a stream function that when enumerated generates a list of dates with a specified precision of either :years, :quarters, :months, :weeks or :days. This function has the same arguments and generates the same results as Cldr.Calendar.interval/3 except it generates the results lazily. Adds :days_of_week option to Cldr.Calendar.localize/3 which returns a list of the localized names of the days of the week in calendar order. Adds calendar_base/0 to identify whether the calendar is week or month based. Bug Fixes Fix Cldr.Calendar.day_of_week/1 for week-based calendars Changelog for Cldr Calendars v0.3.0 This is the changelog for Cldr v0.3.0 released on April 16th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Calendar.interval/3 which generates an enumerable list of dates with a specified precision of either :years, :quarters, :months, :weeks or :days. Examples: iex&gt; import Cldr.Calendar.Sigils Cldr.Calendar.Sigils iex&gt; d = ~d[2019-01-31] %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019} iex&gt; d2 = ~d[2019-05-31] %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019} iex&gt; Cldr.Calendar.interval d, 3, :months [ %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 4, year: 2019} ] iex&gt; Cldr.Calendar.interval d, d2, :months [ %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 4, year: 2019}, %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019} ] Changelog for Cldr Calendars v0.2.0 This is the changelog for Cldr v0.2.0 released on April 14th, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes All calendars now return {year, month, day} tuples from date_from_iso_days/1. Previously in some cases they returned a Date.t first_day_of_year/1 and last_day_of_year/1, first_gregorian_day_of_year/1 and last_gregorian_day_of_year/1 now all return a Date.t or an error tuple. Previously the returned result types were inconsistent. Remove first_gregorian_day_of_year/1 and last_gregorian_day_of_year/1 from Cldr.Calendar callbacks. Enhancements Adds Cldr.Calendar.Julian implementing the Julian calendar. This calendar does not implement week/2, week_of_year/3 or iso_week_of_year/3. Bug Fixes Fixes calculating negative offsets for months in a week-based calendar. Thanks to @bglusman. Closes #2. Changelog for Cldr Calendars v0.1.0 This is the changelog for Cldr v0.1.0 released on April 5th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Initial release. See the README for a description of this project."}]